summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xbuild/buildcheck.sh8
-rw-r--r--configure.in2
2 files changed, 5 insertions, 5 deletions
diff --git a/configure.in b/configure.in
index c4d86d492..de8fa336b 100644
--- a/configure.in
+++ b/configure.in
@@ -4,7 +4,7 @@ dnl
dnl Process this file with autoconf to produce a configure script.
dnl Use ./buildconf to prepare build files and run autoconf for APR.
-AC_PREREQ(2.50)
+AC_PREREQ(2.59)
AC_INIT(build/apr_common.m4)
AC_CONFIG_HEADER(include/arch/unix/apr_private.h)
diff --git a/build/buildcheck.sh b/build/buildcheck.sh
index c23681001..532602e91 100755
--- a/build/buildcheck.sh
+++ b/build/buildcheck.sh
@@ -14,18 +14,18 @@ py_version=`python -c 'import sys; print sys.version' 2>&1|sed 's/ .*//;q'`
echo "buildconf: python version $py_version (ok)"
fi
# autoconf 2.50 or newer
ac_version=`${AUTOCONF:-autoconf} --version 2>/dev/null|sed -e 's/^[^0-9]*//;s/[a-z]* *$//;q'`
if test -z "$ac_version"; then
echo "buildconf: autoconf not found."
-echo " You need autoconf version 2.50 or newer installed"
+echo " You need autoconf version 2.59 or newer installed"
echo " to build APR from SVN."
exit 1
fi
IFS=.; set $ac_version; IFS=' '
-if test "$1" = "2" -a "$2" -lt "50" || test "$1" -lt "2"; then
+if test "$1" = "2" -a "$2" -lt "59" || test "$1" -lt "2"; then
echo "buildconf: autoconf version $ac_version found."
-echo " You need autoconf version 2.50 or newer installed"
+echo " You need autoconf version 2.59 or newer installed"
echo " to build APR from SVN."
exit 1
else
@@ -14,18 +14,18 @@ py_version=`python -c 'import sys; print sys.version' 2>&1|sed 's/ .*//;q'`
echo "buildconf: python version $py_version (ok)"
fi
-# autoconf 2.50 or newer
+# autoconf 2.59 or newer
ac_version=`${AUTOCONF:-autoconf} --version 2>/dev/null|sed -e 's/^[^0-9]*//;s/[a-z]* *$//;q'`
if test -z "$ac_version"; then